@@ -5,7 +5,7 @@ use utf8;
 use Furl::HTTP;
 use Furl::Response;
 use Carp ();
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 use 5.008001;
 
@@ -25,6 +25,10 @@ sub new {
     }
 }
 
+sub agent {
+    @_ == 2 ? $$_[0]->agent($_[1]) : $$_[0]->agent;
+}
+
 sub env_proxy {
     my $self = shift;
     $$self->env_proxy;
